@@ -673,8 +673,7 @@ class Database(object):
         except UnimplementedError:
             # Inmemory backends don't expose metadata, so just return
             # since they can't persist anything anyway!
-            pass
-        return
+            return set()
 
     def meta_refresh(self, retry_limit=RETRY_LIMIT):
         self.parsers_by_language = {}
@@ -685,7 +684,7 @@ class Database(object):
         self.query_cache = LRUDict(limit=self.query_cache_limit)
 
         self._metadata_keyset = self._get_metadata_keyset()
-        for k in list(self._metadata_keyset):
+        for k in self._metadata_keyset:
             op = lambda: self.backend.get_metadata(k)
             val = self.retry_if_modified(op, retry_limit, False)
             if k.startswith(self.relevance_prefix):
